@@ -20,18 +20,18 @@ import os
 import shutil
 import tempfile
 
-FIELDS = dict(
-    background_color="#ff0000",
-    color_scheme="default",
-    font="monospace 12",
-    foreground_color="#00ff00",
-    link_color="#0000ff",
-    pixels_above_lines=1,
-    pixels_below_lines=0,
-    text_view_max_chars=160,
-    text_view_max_lines=45,
-    visited_link_color="#ffff00",
-)
+FIELDS = {
+    "background_color": "#ff0000",
+    "color_scheme": "default",
+    "font": "monospace 12",
+    "foreground_color": "#00ff00",
+    "link_color": "#0000ff",
+    "pixels_above_lines": 1,
+    "pixels_below_lines": 0,
+    "text_view_max_chars": 160,
+    "text_view_max_lines": 45,
+    "visited_link_color": "#ffff00",
+}
 
 
 class TestConfigurationStore(nfoview.TestCase):
@@ -47,23 +47,23 @@ class TestConfigurationStore(nfoview.TestCase):
     def teardown_method(self, method):
         shutil.rmtree(self.temp_dir)
 
-    def test_read_from_file(self):
-        nfoview.conf.write_to_file()
+    def test_read(self):
+        nfoview.conf.write()
         nfoview.conf.restore_defaults()
-        nfoview.conf.read_from_file()
+        nfoview.conf.read()
         for name, value in FIELDS.items():
             assert getattr(nfoview.conf, name) == value
 
     def test_restore_defaults(self):
         nfoview.conf.restore_defaults()
-        defaults = dict(nfoview.config._DEFAULTS)
+        defaults = dict(nfoview.config.DEFAULTS)
         defaults["version"] = nfoview.__version__
         for name, value in defaults.items():
             assert getattr(nfoview.conf, name) == value
 
-    def test_write_to_file(self):
-        nfoview.conf.write_to_file()
+    def test_write(self):
+        nfoview.conf.write()
         nfoview.conf.restore_defaults()
-        nfoview.conf.read_from_file()
+        nfoview.conf.read()
         for name, value in FIELDS.items():
             assert getattr(nfoview.conf, name) == value
