@@ -15,61 +15,43 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-"""Base class for unit test cases."""
-
 import atexit
 import os
 import tempfile
 
-__all__ = ("TestCase",)
-
 
 class TestCase:
 
-    """
-    Base class for unit test cases.
-
-    Unit tests are designed to be run with ``py.test``, ``nose`` or something
-    compatible. Tests should use plain ``assert`` statements to allow multiple
-    different tools to be used to run the tests.
-    """
-
     def assert_raises(self, exception, function, *args, **kwargs):
-        """Assert that calling `function` raises `exception`."""
         try:
             function(*args, **kwargs)
         except exception:
             return
-        raise AssertionError("{} failed to raise {}"
-                             .format(repr(function),
-                                     repr(exception)))
+        raise AssertionError(
+            "{!r} failed to raise {!r}"
+            .format(function, exception))
 
     def new_nfo_file(self):
-        """Return path to a new temporary NFO file."""
         handle, path = tempfile.mkstemp()
         f = os.fdopen(handle, "w")
         f.write("qwertyuiop asdfghjkl zxcvbnm\n")
-        f.write("http://home.gna.org/nfoview\n")
+        f.write("https://otsaloma.io/nfoview/\n")
         f.close()
         atexit.register(os.remove, path)
         return path
 
     def setUp(self):
-        """Compatibility alias for :meth:`setup_method`."""
         self.setup_method(None)
 
     def setup_method(self, method):
-        """Set state for executing tests in `method`."""
         pass
 
     def tearDown(self):
-        """Compatibility alias for :meth:`teardown_method`."""
         self.teardown_method(None)
 
     def teardown_method(self, method):
-        """Remove state set for executing tests in `method`."""
         pass
 
     def test___init__(self):
-        """Make sure that :meth:`setup_method` is always run."""
+        # Make sure that setup_method is always run.
         pass
